@@ -475,6 +475,7 @@ int vk_req(xmlDocPtr reqXml, xmlDocPtr* doc, const struct msa_module* info)
     char* error_code = NULL;
     gchar* func_val = NULL;
     xmlNodePtr node = NULL;
+    gchar* no_auth = NULL;
 
     struct ProfileData *cp = (struct ProfileData *)profile_get_by_id(info->id);
     msa_debug("%s:%d:%s: id=%s, cp->login=%s", __FILE__, __LINE__, __FUNCTION__, info->id, cp->login);
@@ -486,11 +487,15 @@ int vk_req(xmlDocPtr reqXml, xmlDocPtr* doc, const struct msa_module* info)
     msa_debug("IN VK_REQ!!! %d\n", global_req);
     counter = 0;
     msa_xmlDocDump(stdout, reqXml);
+    node = xpath_get_node("//Request", reqXml);
+    if(node != NULL)
+        no_auth = xmlGetProp(node, "noAuthorize");
 
     func_val = (gchar*)get_req_function(reqXml);
     if (g_strcmp0(func_val, "setSettings") != 0
         && g_strcmp0(func_val, "getSettings") != 0)
-        init_status = initialization(cp);
+        if(no_auth == NULL || g_strcmp0(no_auth, "true") != 0)
+            init_status = initialization(cp);
     g_free(func_val);
 
     attempts = 0;
@@ -504,13 +509,22 @@ int vk_req(xmlDocPtr reqXml, xmlDocPtr* doc, const struct msa_module* info)
             info_message(DRV_AUTH_ERROR_CODE, *doc, DRV_AUTH_ERROR, 1);
             return 0;
         }
-                 
     }
     if (process_request(cp, reqXml, doc) == 1){
         info_message(DRV_REQ_ERROR_CODE, *doc, DRV_REQ_ERROR, 1);
         return 0;
     }
 
+    node = xpath_get_node("//Response[@function != 'errorMessage']", *doc);
+    if (node != NULL){
+        if(init_status == 3) {
+            xmlSetProp(node, "authorized", "true");
+        }
+        if(init_status == 0) {
+            xmlSetProp(node, "authorized", "false");
+        }
+    }                 
+
     node = xpath_get_node("//Response[@function='errorMessage']/Params/string[@name='code']", *doc);
     if (node != NULL){
         msa_debug("error occured");
@@ -518,9 +532,14 @@ int vk_req(xmlDocPtr reqXml, xmlDocPtr* doc, const struct msa_module* info)
         if(g_strcmp0(error_code, DRV_AUTH_ERROR_CODE) == 0 
             || g_strcmp0(error_code, "3") == 0
             || g_strcmp0(error_code, "4") == 0){
-            if (authorize(cp) == 0) {
-                xmlFreeDoc(*doc);
-                process_request(cp, reqXml, doc);
+            if(no_auth == NULL || g_strcmp0(no_auth, "true") != 0) {
+                if (authorize(cp) == 0) {
+                    xmlFreeDoc(*doc);
+                    process_request(cp, reqXml, doc);
+                    node = xpath_get_node("//Response[@function != 'errorMessage']", *doc);
+                    if (node != NULL)
+                        xmlSetProp(node, "authorized", "true");
+                }
             }
         }
         g_free(error_code);
@@ -549,6 +568,7 @@ int initialization(struct ProfileData *cp)
             msa_debug("dr_vk: Could not get remixmid, remixsid, auth_status = %d \n", auth_status); 
             return auth_status;
         }
+        return 3;
     }
     msa_debug("init END");
     return 0;
@@ -680,7 +700,25 @@ int authorize(struct ProfileData *cp)
 {
     int ret_code = 0;
     gchar* back_url = NULL;
-    gchar* port = g_strdup_printf("%d", info_port);
+
+    gchar *proxy = info_proxy;
+    gint port = info_port;
+    if (proxy == NULL)
+    {
+	/* try to get system proxy from gconf */
+	GConfClient *client = gconf_client_get_default ();
+	gboolean hasProxy = gconf_client_get_bool (client, GCONF_PROXY_USE, NULL);
+	msa_debug("%s:%d:%s: hasProxy=%d", __FILE__, __LINE__, __FUNCTION__, hasProxy);
+	if (hasProxy) {
+	    proxy = gconf_client_get_string (client, GCONF_PROXY_HOST, NULL);
+	    port = gconf_client_get_int (client, GCONF_PROXY_PORT, NULL);
+	    msa_debug("%s:%d:%s: host=%s, port=%d", __FILE__, __LINE__, __FUNCTION__, proxy, port);
+	}
+	g_object_unref(client);
+    }
+    gchar* sPort = g_strdup_printf("%d", port);
+
+    msa_debug("%s:%d:%s: use proxy=%s:%d", __FILE__, __LINE__, __FUNCTION__, proxy, port);
 
     if (cp == NULL){
         msa_debug("can't authorize, no profile!");
@@ -690,17 +728,17 @@ int authorize(struct ProfileData *cp)
 #ifdef TEST
     back_url = g_strdup(TEST_AUTH_RESPONSE);
 #else  
-    g_debug("Try call webauth with %s = %s", CLIENT_ID_PARAM, cp->id);
+    msa_debug("Try call webauth with %s = %s", CLIENT_ID_PARAM, cp->id);
     char *patterns[] = { REGEXP_PARAM, LOGIN_SUCCESS, TITLE_PARAM, cp->id, CLIENT_ID_PARAM, TITLE_VKONTAKTE, ACCOUNT_ID_PARAM, cp->id};
     char **patt_arr = patterns;
-    back_url = webauth(AUTH_URL, info_proxy, port, "", "", patt_arr, 8, cp->id);
+    back_url = webauth(AUTH_URL, proxy, sPort, "", "", patt_arr, 8, cp->id);
 
 #endif
     //msa_debug("back_url = %s", back_url);
     ret_code = parse_auth(cp, back_url);
     if(back_url != NULL)
         g_free(back_url);
-    g_free(port);
+    g_free(sPort);
    return ret_code;
 }
 
@@ -782,6 +820,31 @@ int info_message(char* code, xmlDocPtr doc, char* message, int type)
     return 0;
 }
 
+int curl_set_options(CURL *c, const char* proxy, int port)
+{
+    /* disable callbacks for working in multithreads */
+    curl_easy_setopt(c, CURLOPT_NOSIGNAL, 1);
+
+    gchar *curProxy = proxy;
+    gint curPort = port;
+    if (curProxy == NULL)
+    {
+	/* try to get system proxy from gconf */
+	GConfClient *client = gconf_client_get_default ();
+	gboolean hasProxy = gconf_client_get_bool (client, GCONF_PROXY_USE, NULL);
+	msa_debug("%s:%d:%s: hasProxy=%d", __FILE__, __LINE__, __FUNCTION__, hasProxy);
+	if (hasProxy) {
+	    curProxy = gconf_client_get_string (client, GCONF_PROXY_HOST, NULL);
+	    curPort = gconf_client_get_int (client, GCONF_PROXY_PORT, NULL);
+	    msa_debug("%s:%d:%s: host=%s, port=%d", __FILE__, __LINE__, __FUNCTION__, curProxy, curPort);
+	}
+	g_object_unref(client);
+    }
+    curl_easy_setopt(c, CURLOPT_PROXY, curProxy);
+    curl_easy_setopt(c, CURLOPT_PROXYPORT, curPort);
+    curl_easy_setopt(c, CURLOPT_TIMEOUT, 120);
+    curl_easy_setopt(c, CURLOPT_FOLLOWLOCATION, 1);
+}
 
 /**
  * Perform HTTP GET request
@@ -816,16 +879,7 @@ int http_get(const char* url, const char* proxy, int port, char** header, gchar*
 
     curl_easy_setopt(c, CURLOPT_URL, url);
 
-    /* disable callbacks for working in multithreads */
-    curl_easy_setopt(c, CURLOPT_NOSIGNAL, 1);
-
-    /* disable using environment variables for proxy */
-    //if (proxy == NULL)
-	//curl_easy_setopt(c, CURLOPT_PROXY, "");
-    //else
-	curl_easy_setopt(c, CURLOPT_PROXY, proxy);
-    curl_easy_setopt(c, CURLOPT_PROXYPORT, port);
-    curl_easy_setopt(c, CURLOPT_TIMEOUT, 120);
+    curl_set_options(c, proxy, port);
 
     curl_easy_setopt(c, CURLOPT_WRITEFUNCTION, WriteMemoryCallback);
     curl_easy_setopt(c, CURLOPT_HEADERFUNCTION, WriteMemoryCallback);
@@ -907,17 +961,7 @@ int http_post(const char* url, const char* proxy, int port, char* post_data, cha
 
     curl_easy_setopt(c, CURLOPT_URL, url);
 
-    /* disable callbacks for working in multithreads */
-    curl_easy_setopt(c, CURLOPT_NOSIGNAL, 1);
-
-    /* disable using environment variables for proxy */
-    //if (proxy == NULL)
-	//curl_easy_setopt(c, CURLOPT_PROXY, "");
-    //else
-	curl_easy_setopt(c, CURLOPT_PROXY, proxy);
-    curl_easy_setopt(c, CURLOPT_PROXYPORT, port);
-    curl_easy_setopt(c, CURLOPT_TIMEOUT, 120);
-
+    curl_set_options(c, proxy, port);
 
     curl_easy_setopt(c, CURLOPT_POST, 1);
     curl_easy_setopt(c, CURLOPT_POSTFIELDS, post_data);
@@ -1012,16 +1056,7 @@ int http_upload_file(const char* url, const char* proxy, const int port, char**
         curl_easy_setopt(curl, CURLOPT_HTTPHEADER, headerlist);
         curl_easy_setopt(curl, CURLOPT_HTTPPOST, formpost);
         
-        /* disable callbacks for working in multithreads */
-	curl_easy_setopt(curl, CURLOPT_NOSIGNAL, 1);
-
-	/* disable using environment variables for proxy */
-	//if (proxy == NULL)
-	//    curl_easy_setopt(curl, CURLOPT_PROXY, "");
-	//else
-	    curl_easy_setopt(curl, CURLOPT_PROXY, proxy);
-        curl_easy_setopt(curl, CURLOPT_PROXYPORT, port);
-        curl_easy_setopt(curl, CURLOPT_FOLLOWLOCATION, 1);
+        curl_set_options(curl, proxy, port);
 
         curl_easy_setopt(curl, CURLOPT_WRITEFUNCTION, WriteMemoryCallback);
         curl_easy_setopt(curl, CURLOPT_HEADERFUNCTION, WriteMemoryCallback);
